==> approvaltests-3.7.0.tar.gz: approvaltests-3.7.0/approvaltests/reporters/python_native_reporter.py <==
#!/usr/bin/env python

import os
import sys
from difflib import unified_diff

from approvaltests.reporters import get_command_text, Reporter
from approvaltests.utils import ensure_file_exists


class PythonNativeReporter(Reporter):
    """
    A reporter that outputs diff straight
    to standard output.

    This is useful when running in a non-GUI environment,
    such as in Continuous Integration systems.
    """

    def report(self, received_path: str, approved_path: str) -> bool:
        ensure_file_exists(approved_path)
        print(calculate_diff_with_approve_instruction(received_path, approved_path))
        return True

    def __str__(self):
        return self.__class__.__name__

    __repr__ = __str__


def calculate_diff_with_approve_instruction(file1: str, file2: str):
    diff_string = calculate_diff(file1, file2)
    if diff_string.strip():
        approve = get_command_text(file1, file2)
        approve_cmd = "\n\nto approve this result:\n\n" + approve + "\n"
    else:
        approve_cmd = ""
    return diff_string + approve_cmd


def calculate_diff(file1: str, file2: str):
    with open(file1) as f1:
        with open(file2) as f2:
            diff = unified_diff(
                f2.readlines(),
                f1.readlines(),
                os.path.basename(file2),
                os.path.basename(file1),
            )
            diff_string = "".join(diff)
            return diff_string

if __name__ == "__main__":
    fileA, fileB = sys.argv[1:3]
    print(calculate_diff_with_approve_instruction(fileA, fileB))

==> approvaltests-5.0.1.tar.gz: approvaltests-5.0.1/approvaltests/reporters/python_native_reporter.py <==
#!/usr/bin/env python

import os
import sys
from difflib import unified_diff

from approvaltests.reporters.clipboard_reporter import get_command_text
from approvaltests.core.reporter import Reporter
from approvaltests.utils import ensure_file_exists


class PythonNativeReporter(Reporter):
    """
    A reporter that outputs diff straight
    to standard output.

    This is useful when running in a non-GUI environment,
    such as in Continuous Integration systems.
    """

    def report(self, received_path: str, approved_path: str) -> bool:
        ensure_file_exists(approved_path)
        print(calculate_diff_with_approve_instruction(received_path, approved_path))
        return True

    def __str__(self):
        return self.__class__.__name__

    __repr__ = __str__


def calculate_diff_with_approve_instruction(file1: str, file2: str):
    diff_string = calculate_diff(file1, file2)
    if diff_string.strip():
        approve = get_command_text(file1, file2)
        approve_cmd = "\n\nto approve this result:\n\n" + approve + "\n"
    else:
        approve_cmd = ""
    return diff_string + approve_cmd


def calculate_diff(filename1: str, filename2: str):
    with open(filename1, encoding='utf8') as file1:
        with open(filename2, encoding='utf8') as file2:
            diff = unified_diff(
                file2.readlines(),
                file1.readlines(),
                os.path.basename(filename2),
                os.path.basename(filename1),
            )
            diff_string = "".join(diff)
            return diff_string

if __name__ == "__main__":
    print(calculate_diff_with_approve_instruction(sys.argv[1], sys.argv[2]))
